@@ -55,38 +55,36 @@ class MeSHKnowledgeParser(KnowledgeParserBase):
             mesh = etree.parse(file)
             bar.max = int(mesh.xpath("count(//DescriptorRecord)"))
         bar.start()
-        try:
-            with maybe_archive(source, mode='rb') as file:
-                mesh = etree.iterparse(file, events=("end",), tag=['DescriptorRecord'])
-                for event, record in mesh:
-                    bar.next()
-                    dui = record.findtext("DescriptorUI")
-                    norm = record.findtext("./DescriptorName/String")
-                    labels = setlist()
-                    props = defaultdict(list)
-                    labels.add(norm)
-                    for concept in record.iterfind("./ConceptList/Concept"):
-                        for term in concept.iterfind("./TermList/Term"):
-                            tname = term.findtext("String")
-                            labels.add(tname)
-                    labels.remove(norm)
-                    cats = setlist()
-                    branches = setlist()
-                    for tnumber in record.iterfind("./TreeNumberList/TreeNumber"):
-                        number = tnumber.text
-                        props['TreeNumber'].append(number)
-                        branches.add(number[0])
-                        cats.add(MESH_CATEGORIES[number[0]])
-                    props['Category'] = list(cats)
-                    props['Branch'] = list(branches)
-                    props['altForms'] = list(labels)
 
-                    record.clear()
-                    if intersection(allowed_branches, props['Branch']):
-                        term: Term = Term(identifier=dui, preferredForm=norm, properties=props)
-                        yield term
-        finally:
-            bar.finish()
+        with maybe_archive(source, mode='rb') as file:
+            mesh = etree.iterparse(file, events=("end",), tag=['DescriptorRecord'])
+            for event, record in mesh:
+                bar.next()
+                dui = record.findtext("DescriptorUI")
+                norm = record.findtext("./DescriptorName/String")
+                labels = setlist()
+                props = defaultdict(list)
+                labels.add(norm)
+                for concept in record.iterfind("./ConceptList/Concept"):
+                    for term in concept.iterfind("./TermList/Term"):
+                        tname = term.findtext("String")
+                        labels.add(tname)
+                labels.remove(norm)
+                cats = setlist()
+                branches = setlist()
+                for tnumber in record.iterfind("./TreeNumberList/TreeNumber"):
+                    number = tnumber.text
+                    props['TreeNumber'].append(number)
+                    branches.add(number[0])
+                    cats.add(MESH_CATEGORIES[number[0]])
+                props['Category'] = list(cats)
+                props['Branch'] = list(branches)
+                props['altForms'] = list(labels)
+
+                record.clear()
+                if intersection(allowed_branches, props['Branch']):
+                    term: Term = Term(identifier=dui, preferredForm=norm, properties=props)
+                    yield term
 
     @classmethod
     def get_schema(cls) -> KnowledgeParserOptions:
